--- commons-io-1.2-src.src.test.org.apache.commons.io.output.PackageTestSuite.java	Fri Aug  7 11:00:09 2009
+++ commons-io-1.3-src.src.test.org.apache.commons.io.input.PackageTestSuite.java	Fri Aug  7 10:59:33 2009
@@ -1,10 +1,11 @@
 /*
- * Copyright 2004 The Apache Software Foundation.
+ * Licensed to the Apache Software Foundation (ASF) under one or more
+ * contributor license agreements.  See the NOTICE file distributed with
+ * this work for additional information regarding copyright ownership.
+ * The ASF licenses this file to You under the Apache License, Version 2.0
+ * (the "License"); you may not use this file except in compliance with
+ * the License.  You may obtain a copy of the License at
  * 
- * Licensed under the Apache License, Version 2.0 (the "License");
- * you may not use this file except in compliance with the License.
- * You may obtain a copy of the License at
- * 
  *      http://www.apache.org/licenses/LICENSE-2.0
  * 
  * Unless required by applicable law or agreed to in writing, software
@@ -13,15 +14,14 @@
  * See the License for the specific language governing permissions and
  * limitations under the License.
  */
+package org.apache.commons.io.input;
 
-package org.apache.commons.io.output;
-
 import junit.framework.Test;
 import junit.framework.TestSuite;
 import junit.textui.TestRunner;
 
 /**
  * A basic test suite that tests all the IO output package.
  * 
  * @author Stephen Colebourne
  */
@@ -32,13 +32,12 @@
     }
 
     public static Test suite() {
-        TestSuite suite = new TestSuite("IO Utilities - output");
-        suite.addTest(new TestSuite(ByteArrayOutputStreamTestCase.class));
-        suite.addTest(new TestSuite(CountingOutputStreamTest.class));
-        suite.addTest(new TestSuite(DeferredFileOutputStreamTest.class));
-        suite.addTest(new TestSuite(LockableFileWriterTest.class));
-        suite.addTest(new TestSuite(NullOutputStreamTest.class));
-        suite.addTest(new TestSuite(TeeOutputStreamTest.class));
+        TestSuite suite = new TestSuite("IO Utilities - input");
+        suite.addTest(new TestSuite(ClassLoaderObjectInputStreamTest.class));
+        suite.addTest(new TestSuite(CountingInputStreamTest.class));
+        suite.addTest(new TestSuite(NullInputStreamTest.class));
+        suite.addTest(new TestSuite(NullReaderTest.class));
+        suite.addTest(new TestSuite(SwappedDataInputStreamTest.class));
         return suite;
     }
 }
@@ -13,15 +14,14 @@
 
 /**
- * A basic test suite that tests all the IO output package.
+ * A basic test suite that tests all the IO input package.
  * 
  * @author Stephen Colebourne
